@@ -11,7 +11,8 @@ from spacy.tokens import Doc, Span
 
 onnx = importlib.util.find_spec(
     "fast_sentence_transformers"
-) or importlib.util.find_spec("fast-sentence-transformers")if onnx is None:
+) or importlib.util.find_spec("fast-sentence-transformers")
+if onnx is None:
     from sentence_transformers import SentenceTransformer
 else:
     from fast_sentence_transformers import (
